# Wunderkafka

>The power of librdkafka for <s>humans</s> pythons

Wunderkafka provides handful facade for C-powered consumer/producer. It's built on top of the [confluent-kafka](https://pypi.org/project/confluent-kafka/)

For a quick view on what is going on, please check [Quickstart](https://wunderkafka.readthedocs.io/en/stable/pages/quickstart.html) and [Documentation](https://wunderkafka.readthedocs.io/en/stable/)

Installation process described [here](https://wunderkafka.readthedocs.io/en/stable/pages/install.html)
